@@ -1,7 +1,8 @@
 rss_parse <- function(response, list, clean_tags, parse_dates) {
   # spec here: https://validator.w3.org/feed/docs/rss2.html
-  res <- response %>% read_xml()
+  res <- read_xml(response, options = "HUGE")
   geocheck(res)
+
   channel <- xml_find_first(res, "//*[name()='channel']")
   # meta data. Necessary: title, link, description
   metadata <- tibble(
@@ -53,10 +54,26 @@ rss_parse <- function(response, list, clean_tags, parse_dates) {
   entries <- clean_up(entries, "rss", clean_tags, parse_dates)
 
   if (isTRUE(list)) {
-    out <- list(meta = meta, entries = entries)
-    return(out)
+    out <- list(meta = meta, entries = entries) # nocov
+    return(out) # nocov
   } else {
+    if (!has_name(meta, "feed_title")) {
+      meta$feed_title <- NA_character_ # nocov
+    }
     entries$feed_title <- meta$feed_title
-    out <- suppressMessages(full_join(meta, entries))
+    out <- suppressMessages(safe_join(meta, entries))
+    if (is.null(out$error)) {
+      out <- out$result
+      if (all(is.na(out$feed_title))) out <- out %>% select(-feed_title) # nocov
+      return(out)
+    } else {
+      # nocov start
+      meta$tmp <- "temp"
+      entries$tmp <- "temp"
+      out <- suppressMessages(full_join(meta, entries))
+      out <- out %>% select(-tmp)
+      return(out)
+      # nocov end
+    }
   }
 }
